"use client";

import Link from "next/link";
import {useEffect, useState} from "react";
import {IoChevronForwardOutline} from "react-icons/io5";
import {BsFacebook, BsInstagram, BsWhatsapp} from "react-icons/bs";
import Image from "next/image";
import { navbarData, navbarLogo, villaData } from "@/app/data/content";

export default function Footer() {
  const [scrollY, setScrollY] = useState(0);
  const currentYear = new Date().getFullYear();

  const handleScroll = () => {
    setScrollY(window.scrollY);
  };

  useEffect(() => {
    window.addEventListener("scroll", handleScroll);
    return () => {
      window.removeEventListener("scroll", handleScroll);
    };
  }, []);

  return (
    <>
      <footer className="">
        <div className="lg:max-w-6xl mx-auto py-5 space-y-10 lg:space-y-2">
          <hr className="w-[90%] lg:w-full border-main mx-auto" />
          <div className="w-full py-0 lg:py-5 px-5 lg:px-0 lg:mx-auto grid grid-cols-1 lg:grid-cols-6 gap-5 items-center">
            <Image
              src={navbarLogo.logo_dark}
              alt='Villa Batu'
               width={180}
               height={126}
              className="object-cover w-32 mx-auto"
            />
            <div className="lg:col-span-2">
              <span className="text-main">{villaData.location_address}</span>
            </div>
            <div className="lg:col-span-2 flex flex-col text-main">
            <a href="https://wa.me/+6287765107836" target="_blank">
                Reservation: +62 877 6510 7836
              </a>
              <a href="mailto:hello@thetropicaldoor.com" target="_blank">
                Email: hello@thetropicaldoor.com
              </a>
            </div>
            <div className="lg:col-end-7 lg:text-right">
              <a
                href={villaData.location_maps}
                target="_blank"
                className="underline underline-offset-4 font-bold text-main"
              >
                Get directions
              </a>
            </div>
          </div>

          <div className="w-full py-0 lg:py-5 px-5 lg:px-0 lg:mx-auto grid grid-cols-1 lg:grid-cols-6 gap-5 items-center">
            <div className="text-main">Follow us on</div>
            <div className="lg:col-span-2 flex flex-row gap-4">
              <a href={navbarData.facebook} target="_blank">
                <div className="bg-main rounded-lg p-[10px] flex items-center">
                  <BsFacebook size={20} className="text-white" />
                </div>
              </a>
              <a href={navbarData.instagram} target="_blank">
                <div className="bg-main rounded-lg p-[10px] flex items-center">
                  <BsInstagram size={20} className="text-white" />
                </div>
              </a>
              <a href={navbarData.waLink} target="_blank">
                <div className="bg-main rounded-lg p-[10px] flex items-center">
                  <BsWhatsapp size={20} className="text-white" />
                </div>
              </a>
            </div>
            <div className="lg:col-span-3 lg:text-right">
              <span className="text-main">
                © Copyright {currentYear} {villaData.villa_name} All Rights Reserved.
                <br className="hidden lg:block" /> Managed by{" "}
                <a href="https://thetropicaldoor.com" target="_blank">
                  The Tropical Door
                </a>
              </span>
            </div>
          </div>
        </div>
      </footer>
      <div
        className={`${
          scrollY > 0 ? "opacity-100 translate-y-0" : "opacity-0 translate-y-4"
        } transition-all ease-in-out duration-500 transform fixed bottom-28 w-fit right-5 lg:right-10 z-10`}
      >
        <a
         href={navbarData.waLink} target="_blank"
          className="bg-main p-4 border border-white rounded-full flex items-center"
        >
          <BsWhatsapp size={30} className="text-white" />
        </a>
      </div>
      <div
        className={`${
          scrollY > 0 ? "opacity-100 translate-y-0" : "opacity-0 translate-y-4"
        } w-full sticky bottom-0 z-10 flex justify-center items-center py-5 gap-4 bg-main transition-all ease-in-out duration-500 transform`}
      >
        <span className="text-white">Book your stay</span>
        <IoChevronForwardOutline size={20} className="text-white" />
        <Link
          href="/availability"
          className="p-3 bg-white text-main rounded text-base tracking-wide font-Soraa"
        >
          Check Availability
        </Link>
      </div>
    </>
  );
}
